@@ -24,6 +24,8 @@ Pure Python module to hyphenate text, inspired by Ruby's Text::Hyphen.
 import os
 import re
 
+VERSION = __version__ = '0.11.0'
+
 __all__ = ('Pyphen', 'LANGUAGES', 'language_fallback')
 
 # cache of per-file HyphDict objects
@@ -136,7 +138,7 @@ class HyphDict(object):
                     lambda match: chr(int(match.group(1), 16)), pattern)
 
                 # read nonstandard hyphen alternatives
-                if '/' in pattern:
+                if '/' in pattern and '=' in pattern:
                     pattern, alternative = pattern.split('/', 1)
                     factory = AlternativeParser(pattern, alternative)
                 else:
